# !/usr/bin/env python
# encoding:utf-8
 
 
import os
from pyinotify import WatchManager, Notifier, \
    ProcessEvent, IN_DELETE, IN_CREATE, IN_MODIFY, IN_CLOSE_WRITE

from gi.repository import GObject as gobject

import dbus
import dbus.service
import dbus.mainloop.glib
import threading

class DemoException(dbus.DBusException):
    _dbus_error_name = 'org.ukui.LockStatus'

class SomeObject(dbus.service.Object):
    @dbus.service.method("org.ukui.LockStatus",
                         in_signature='', out_signature='(ss)')
    def GetTuple(self):
        return ("Hello Tuple", " from example-service.py")
    
    @dbus.service.signal("org.ukui.LockStatus")
    def lock(self):
        return ("lock")

    @dbus.service.signal("org.ukui.LockStatus")
    def unlock(self):
        return ("unlock")
 
def call_back(file):
    print("call back at file:{}".format(file))
 


class EventHandler(ProcessEvent):
    """事件处理"""
    def __init__(self,fun):
        self.fun = fun
 
    def process_IN_CREATE(self, event):
        print("Create file: %s " % os.path.join(event.path, event.name))
 
    def process_IN_DELETE(self, event):
        print("Delete file: %s " % os.path.join(event.path, event.name))
 
    def process_IN_MODIFY(self, event):
        print("Modify file: %s " % os.path.join(event.path, event.name))
 
    def process_IN_CLOSE_WRITE(self, event):
        print("Close Write file: %s " % os.path.join(event.path, event.name))
        filename = os.path.join(event.path, event.name)
        #解锁，文件写入0 ; 锁屏，文件 写入1
        if filename == "/etc/default/lockstatus":
            print("-------test is ", filename)
            with open(filename,"r") as f:
                lstatus = f.readline()
                if lstatus == "1":
                    object.lock()
                if lstatus== "0":
                    object.unlock()
        if self.fun != None:
            self.fun(os.path.join(event.path, event.name))
 
 
def FSMonitor(path='.',fun=None):
    wm = WatchManager()
    mask = IN_DELETE | IN_CREATE | IN_MODIFY | IN_CLOSE_WRITE
    notifier = Notifier(wm, EventHandler(fun))
    wm.add_watch(path, mask, rec=True)
    print('now starting monitor %s' % (path))
    while True:
        try:
            notifier.process_events()
            if notifier.check_events():
                notifier.read_events()
        except KeyboardInterrupt:
            notifier.stop()
            break

if __name__ == "__main__":
    lockStatus = "/etc/default/lockstatus"
    with open(lockStatus,"w") as Lfile:
        Lfile.write("0")
    pr1 = threading.Thread(target=FSMonitor, args=("/etc/default", call_back, ))
    pr1.start()

    dbus.mainloop.glib.DBusGMainLoop(set_as_default=True)
    session_bus = dbus.SystemBus()
    name = dbus.service.BusName("org.ukui.LockStatus", session_bus)
    object = SomeObject(session_bus, '/SomeObject')
    print("Running example service.")
    mainloop = gobject.MainLoop()
    mainloop.run()

    pr1.join()

